import { AfterViewInit, Renderer2, ChangeDetectorRef, EventEmitter, ViewContainerRef, ComponentFactoryResolver, Injector, ComponentRef, OnChanges, SimpleChanges, ElementRef, OnInit, OnDestroy } from '@angular/core';
import { MatSort } from '@angular/material/sort';
import { MatTableDataSource } from '@angular/material/table';
import { ICopyCodeTooltips, IRawToggleLabels } from '@covalent/highlight';
import * as i0 from "@angular/core";
export interface ITdFlavoredMarkdownButtonClickEvent {
    text: string;
    data: string;
}
export interface ITdFlavoredMarkDownTableColumn {
    label: string;
    name: string;
    numeric: boolean;
}
export declare class TdFlavoredMarkdownTableComponent implements OnInit, AfterViewInit {
    columnDefs: ITdFlavoredMarkDownTableColumn[];
    data: unknown[];
    sort: MatSort;
    displayedColumns: string[];
    dataSource: MatTableDataSource<unknown>;
    ngOnInit(): void;
    ngAfterViewInit(): void;
    static ɵfac: i0.ɵɵFactoryDeclaration<TdFlavoredMarkdownTableComponent, never>;
    static ɵcmp: i0.ɵɵComponentDeclaration<TdFlavoredMarkdownTableComponent, "ng-component", never, { "columnDefs": "columnDefs"; "data": "data"; }, {}, never, never, false, never>;
}
export declare class TdFlavoredMarkdownButtonComponent {
    display: string;
    text: string;
    data: string;
    clicked: EventEmitter<ITdFlavoredMarkdownButtonClickEvent>;
    emitClick(): void;
    static ɵfac: i0.ɵɵFactoryDeclaration<TdFlavoredMarkdownButtonComponent, never>;
    static ɵcmp: i0.ɵɵComponentDeclaration<TdFlavoredMarkdownButtonComponent, "ng-component", never, { "text": "text"; "data": "data"; }, { "clicked": "clicked"; }, never, never, false, never>;
}
export declare class TdFlavoredMarkdownContainerDirective {
    viewContainerRef: ViewContainerRef;
    private _renderer;
    constructor(viewContainerRef: ViewContainerRef, _renderer: Renderer2);
    clear(): void;
    static ɵfac: i0.ɵɵFactoryDeclaration<TdFlavoredMarkdownContainerDirective, never>;
    static ɵdir: i0.ɵɵDirectiveDeclaration<TdFlavoredMarkdownContainerDirective, "[tdFlavoredMarkdownContainer]", never, {}, {}, never, never, false, never>;
}
export type IReplacerFunc<T> = (componentRef: ComponentRef<T>, ...args: any[]) => void;
export declare class TdFlavoredMarkdownComponent implements AfterViewInit, OnChanges, OnDestroy {
    private _componentFactoryResolver;
    private _renderer;
    private _changeDetectorRef;
    private _injector;
    private _elementRef;
    private _content;
    private _simpleLineBreaks;
    private _hostedUrl;
    private _anchor;
    private _components;
    private _viewInit;
    /**
     * content?: string
     *
     * Markdown format content to be parsed as material/covalent markup.
     *
     * e.g. README.md content.
     */
    set content(content: string);
    /**
     * simpleLineBreaks?: string
     *
     * Sets whether newline characters inside paragraphs and spans are parsed as <br/>.
     * Defaults to false.
     */
    set simpleLineBreaks(simpleLineBreaks: boolean);
    /**
     * hostedUrl?: string
     *
     * If markdown contains relative paths, this is required to generate correct urls
     *
     */
    set hostedUrl(hostedUrl: string);
    /**
     * anchor?: string
     *
     * Anchor to jump to
     *
     */
    set anchor(anchor: string);
    /**
     * copyCodeToClipboard?: boolean
     *
     * Display copy button on code snippets to copy code to clipboard.
     *
     */
    copyCodeToClipboard?: boolean | undefined;
    /**
     * copyCodeTooltips?: ICopyCodeTooltips
     *
     * Tooltips for copy button to copy and upon copying.
     */
    copyCodeTooltips?: ICopyCodeTooltips;
    /**
     * toggleRawCode?: boolean
     *
     * Display button to toggle raw code view
     */
    toggleRawCode: boolean;
    /**
     * rawToggleLabels?: IRawToggleLabels
     *
     * Labels for raw code toggle button
     */
    rawToggleLabels?: IRawToggleLabels;
    /**
     * useCfmList?: boolean = false;
     * Use CFM list component instead of vanilla markdown list. Used in covalent documentation app.
     */
    useCfmList?: boolean | undefined;
    /**
     * contentReady?: function
     * Event emitted after the markdown content rendering is finished.
     */
    contentReady: EventEmitter<undefined>;
    /**
     * buttonClicked?: ITdFlavoredMarkdownButtonClickEvent
     * Event emitted when a button is clicked
     * Is an object containing text and data of button
     */
    buttonClicked: EventEmitter<ITdFlavoredMarkdownButtonClickEvent>;
    container: TdFlavoredMarkdownContainerDirective;
    private _destroy$;
    constructor(_componentFactoryResolver: ComponentFactoryResolver, _renderer: Renderer2, _changeDetectorRef: ChangeDetectorRef, _injector: Injector, _elementRef: ElementRef);
    ngOnChanges(changes: SimpleChanges): void;
    ngAfterViewInit(): void;
    ngOnDestroy(): void;
    refresh(): void;
    private _loadContent;
    private _render;
    private _replaceComponent;
    private _replaceCheckbox;
    private _replaceButtons;
    private _replaceCodeBlocks;
    private _replaceTables;
    private _replaceLists;
    static ɵfac: i0.ɵɵFactoryDeclaration<TdFlavoredMarkdownComponent, never>;
    static ɵcmp: i0.ɵɵComponentDeclaration<TdFlavoredMarkdownComponent, "td-flavored-markdown", never, { "content": "content"; "simpleLineBreaks": "simpleLineBreaks"; "hostedUrl": "hostedUrl"; "anchor": "anchor"; "copyCodeToClipboard": "copyCodeToClipboard"; "copyCodeTooltips": "copyCodeTooltips"; "toggleRawCode": "toggleRawCode"; "rawToggleLabels": "rawToggleLabels"; "useCfmList": "useCfmList"; }, { "contentReady": "contentReady"; "buttonClicked": "buttonClicked"; }, never, ["*"], false, never>;
}
